<TS language="ro_RO" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Despre Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Creează o adresă nouă</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiază adresa selectată în clipboard</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiază</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Arat? cod &amp;QR</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Semneaz? un mesaj pentru a dovedi c? de?ineti o adres? Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Semneaz? &amp;Mesajul</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verific? un mesaj pentru a v? asigura c? a fost semnat cu o anumit? adres? Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verific? mesajul</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Şterge adresele curent selectate din listă</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Agend?</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Acestea sunt adresele Gridcoin pentru a primi pl??i. Poate dori?i sa da?i o adresa noua fiecarui expeditor pentru a putea ?ine eviden?a la cine efectueaz? pl?ti.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Şterge</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiaz? &amp;eticheta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editeaz?</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Export? datele din Agend?</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Eroare la exportare</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Nu s-a putut scrie în fi?ier %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etichet?</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres?</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(f?r? etichet?)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogul pentru fraza de acces</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introduceţi fraza de acces</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Frază de acces nouă</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetaţi noua frază de acces</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Serve?te pentru a dezactiva sendmoneyl atunci când sistemul de operare este compromis. Nu ofer? nicio garan?ie real?.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Doar pentru staking</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cripteaz? portofelul</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Aceast? ac?iune necesit? fraza ta de acces pentru deblocarea portofelului.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Deblocheaz? portofelul</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Schimb? fraza de acces</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introdu vechea ?i noua parol? pentru portofel.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirm? criptarea portofelului</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Atentie: Daca encriptezi portofelul si iti uiti parola, &lt;b&gt;VEI PIERDE TOATA MONEDELE&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Sunte?i sigur c? dori?i s? cripta?i portofelul electronic?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portofel criptat</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin se va inchide pentru a termina procesul de encriptie. Aminti?i-v?, criptarea portofelul dumneavoastr? nu poate proteja pe deplin monedele dvs. de a fi furate de  infectarea cu malware a computerului.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANT: Orice copie de siguranta facuta in prealabil portofelului dumneavoastra ar trebui inlocuita cu cea generata cel mai recent fisier criptat al portofelului. Pentru siguranta, copiile de siguranta vechi ale portofelului ne-criptat vor deveni inutile de indata ce veti incepe folosirea noului fisier criptat al portofelului.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Criptarea portofelului a e?uat</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Criptarea portofelului a e?uat din cauza unei erori interne. Portofelul t?u nu a fost criptat.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Frazele de acces introduse nu se potrivesc.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Deblocarea portofelului a e?uat</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Fraza de acces introdus? pentru decriptarea portofelului a fost incorect?.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Parola portofelului electronic a fost schimbat?.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Atentie! Caps Lock este pornit</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>A ap?rut o eroare fatal?. Gridcoin nu mai poate continua în condi?ii de siguran?? ?i va iesi.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portofel</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Imagine de ansamblu</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Arată o stare generală de ansamblu a portofelului</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Trimite</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Trimite monede c?tre o adres? Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>P&amp;rimeşte</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Arat? lista de adrese pentru primire pl??i</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Răsfoire istoric tranzacţii</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Editeaz? lista de adrese si etichete stocate</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Ieşire</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Închide aplicaţia</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>Despre Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Arat? informa?ii despre Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opţiuni...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modific? op?iuni de configurare pentru Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Arată/Ascunde</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Cript&amp;ează portofelul...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>S&amp;chimbă parola...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Schimbă fraza de acces folosită pentru criptarea portofelului</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Deblocheaz? portofelul</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Deblocheaz? portofelul</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>Blocheaz? portofelul</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Blocheaz? portofelul</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Semnează &amp;mesaj...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifică mesaj...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Export?</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Export? datele din tab-ul curent într-un fi?ier</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Fereastra de &amp;depanare</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Deschide consola de depanare şi diagnosticare</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fişier</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;jutor</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Clientul Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizat</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Se actualizează...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Ultimul bloc primit a fost generat %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Aceast? tranzactie este peste limita admisa. Pute?i sa trimite?i pentru o taxa de %1, care este pentru nodurile care proceseaza tranzactia si ajuta la sprijinirea retelei. Vrei s? pl?te?ti taxa?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Confirm? comisinoul tranzac?iei</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Tranzacţie expediată</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Tranzacţie recepţionată</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Manipulare URI</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI nu poate fi parsatt! Cauza poate fi o adresa Gridcoin invalid? sau parametrii URI malforma?i.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portofelul este &lt;b&gt;criptat&lt;/b&gt; iar în momentul de faţă este &lt;b&gt;blocat&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>F? o copie de siguran?? a portofelului</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Date portofel(*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Copia de rezerva a esuat</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Eroare la încercarea de a salva datele portofelului în noua loca?ie.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alert? re?ea</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantitate:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Octeţi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumă:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Taxă:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Controleaz? moneda</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Ie?ire minim?: </translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>După taxă:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Schimb:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumă</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmări</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichet?</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres?</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiaz? adresa</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiaz? eticheta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiaz? suma</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiaz? ID tranzac?ie</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia?i quantitea</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia?i taxele</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia?i dup? taxe</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia?i octe?i</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia?i ie?ire minim?:</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia?i schimb</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>da</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nu</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Aceasta eticheta se inroseste daca marimea tranzactiei este mai mare de 10000 bytes.

Acest lucru inseamna ca este nevoie de o taxa de cel putin %1 pe kb

Poate varia +/- 1 Byte pe imput.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Aceasta eticheta se inroseste daca oricare din contacte primeste o suma mai mica decat %1.

Acest lucru inseamna ca un comision de cel putin %2 este necesar.

Sume mai mici decat 0.546 ori minimul comisionului de relay sunt afisate ca DUST</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Aceast? eticheta se înroseste dac? schimbul este mai mic de %1.

Acest lucru înseamn? c? o tax? de cel pu?in %2 este necesar?</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(f?r? etichet?)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>schimb? la %1(%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(schimb)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editează adresa</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etichetă</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Eticheta asociat? cu aceast? intrare în agend?</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Adresa asociat? cu aceast? intrare în agend?. Acest lucru poate fi modificat numai pentru adresele de trimitere.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresă</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Noua adres? de primire</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Noua adres? de trimitere</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editeaz? adresa de primire</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editeaz? adresa de trimitere</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Adresa introdus? "%1" nu este o adres? Gridcoin valid?</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Adresa introdus? "%1" se afl? deja în lista de adrese.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Portofelul nu a putut fi deblocat.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generarea noii chei a e?uat.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versiune</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Utilizare:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Optiuni linie de comanda</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opţiuni</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>Reţea</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapare port folosind &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Porne?te Gridcoin imdiat dup? logarea în sistem</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>$Porne?te Gridcoin la logarea în sistem</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Deschide automat portul pentru cientul Gridcoin pe router. Aces lucru este posibil doara daca routerul suporta UPnP si este activat</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Adresa IP a proxy-ului(ex. 127.0.0.1)</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Portul proxy (de exemplu: 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Ascunde fereastra în locul p?r?sirii programului în momentul închiderii ferestrei. Când acest? op?iune e activ?, aplica?ia se va opri doar în momentul select?rii comenzii Quit din menu.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>Limba interfe?ei utilizator poate fi setat aici. Aceast? setare va avea efect dup? repornirea Gridcoin.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Dac? s? arate adrese Gridcoin din lista de tranzac?ie sau nu.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Afi?eaz? adresele în lista de tranzac?ii</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fereastră</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Aplica</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Arată doar un icon în tray la ascunderea ferestrei</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizare în tray în loc de taskbar</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizare fereastră în locul închiderii programului</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Afişare</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Limbă interfaţă utilizator</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unitatea de măsură pentru afişarea sumelor:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Alegeţi subdiviziunea folosită la afişarea interfeţei şi la trimiterea de bitcoin.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Renunţă</translation>
    </message>
    <message>
        <source>default</source>
        <translation>iniţial</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertizare</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Aceasta setare va avea efect dupa repornirea Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Adresa bitcoin pe care aţi specificat-o nu este validă.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation>Disponibil:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Balanţa dvs. curentă de cheltuieli</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nematurizat:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Informatia afisata poate fi depasita.  Portofel se sincronizeaz? automat cu re?eaua Gridcoin dup? ce se stabile?te o conexiune, dar acest proces nu s-a finalizat înc?.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Total al tranzac?iilor care nu au fost confirmate  înc? ?i nu conteaz? fa?? de balan?a curent?</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Balanţa totală curentă</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>Dialog cod QR</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Cerere de plat?</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etichet?</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mesaj:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cantitate:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Salveaz? ca...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Eroare la codarea URl-ului în cod QR.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Suma introdus? nu este valid?, v? rug?m s? verifica?i.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI rezultat este prea lung, încearc? s? reduci textul pentru etichet? / mesaj.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Salveaz? codul QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>indisponibil</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versiune client</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informaţii</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Durata pornirii</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Numărul de conexiuni</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Lanţ de blocuri</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Numărul curent de blocuri</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Data ultimului bloc</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Deschide</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Curăţă</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consolă</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Trafic reţea</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totaluri</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Intrare:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ieşire:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Fişier jurnal depanare</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Curăţă consola</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Pe testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Blocurile totale estimate</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Deschideti fisierul de depanare Gridcoin din folderul curent. Acest lucru poate dura cateva secunde pentru fisiere de log mari.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Optiuni linii de comand?</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Arat?</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nume client</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Folosiţi săgetile sus şi jos pentru a naviga în istoric şi &lt;b&gt;Ctrl-L&lt;/b&gt; pentru a curăţa.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Scrieţi &lt;b&gt;help&lt;/b&gt; pentru a vedea comenzile disponibile.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Trimite monede</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Intrări...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>selecţie automată</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fonduri insuficiente!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantitate:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Octeţi:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumă:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Taxă:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Ie?ire minim?: </translation>
    </message>
    <message>
        <source>no</source>
        <translation>nu</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>După taxă:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Schimb?:</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>personalizeaz? schimbarea adresei</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Scoate?i toate câmpuirile de tranzac?ii</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Trimite simultan către mai mulţi destinatari</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Adaugă destinata&amp;r</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Curăţă to&amp;ate</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmă operaţiunea de trimitere</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Trimit&amp;e</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia?i quantitea</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiaz? suma</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia?i taxele</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copia?i dup? taxe</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia?i octe?i</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copia?i ie?ire minim?:</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia?i schimb</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirm? trimiterea de monede</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Sunte?i sigur c? dori?i s? trimite?i %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>?i</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Adresa destinatarului nu este valid?, v? rug?m s? o verifica?i.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Suma de plat? trebuie s? fie mai mare decât 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Suma dep??e?te soldul contului.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Totalul dep??e?te soldul contului dac? se include ?i plata comisionului de %1.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>S-a descoperit o adres? care figureaz? de dou? ori. Expedierea se poate realiza c?tre fiecare adres? doar o singur? dat? pe opera?iune.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Eroare: crearea tranzac?iei a e?uat.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Eroare: tranzac?ia a fost respins?. Acest lucru s-ar putea întâmpla în cazul în care unele dintre monedele din portofel au fost deja cheltuite, cum si cum a?i utilizat o copie a wallet.dat ?i monedele au fost cheltuite în copie dar nu au fost marcate ca ?i cheltuite aici.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(f?r? etichet?)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>Aten?ie: Adres? Gridcoin invalid?</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>ATENTIE: adresa schimb necunoscuta</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Su&amp;mă:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Plăteşte că&amp;tre:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mesaj:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etichetă:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Lipeşte adresa din clipboard</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Alegeti adresa din agenda</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Scoateti acest destinatar</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introdu o etichet? pentru aceast? adres? pentru a fi ad?ugat? în lista ta de adrese</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Semnaturi - Semnează/verifică un mesaj</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Semnează mesaj</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Puteti semna mesaje cu adresa dumneavoastra pentru a demostra ca sunteti proprietarul lor. Aveti grija sa nu semnati nimic vag, deoarece atacurile de tip phishing va pot pacali sa le transferati identitatea. Semnati numai declaratiile detaliate cu care sunteti deacord.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Alegeti o adresa din agenda</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Lipeşte adresa copiată din clipboard</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduceţi mesajul pe care vreţi să-l semnaţi, aici</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiază semnatura curentă în clipboard-ul sistemului</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Semneaz? un mesaj pentru a dovedi c? de?ineti o adres? Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Semnează &amp;mesaj</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Resetează toate cîmpurile mesajelor semnate</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Curăţă to&amp;ate</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifică mesaj</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Introduceti adresa de semnatura, mesajul (asigurati-va ca ati copiat spatiile, taburile etc. exact) si semnatura dedesubt pentru a verifica mesajul. Aveti grija sa nu cititi mai mult in semnatura decat mesajul in sine, pentru a evita sa fiti pacaliti de un atac de tip man-in-the-middle.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Verific? un mesaj pentru a v? asigura c? a fost semnat cu o anumit? adres? Gridcoin</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Resetează toate cîmpurile mesajelor semnate</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Click "Semneaza msajul" pentru a genera semnatura</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Introduceti semnatura Gridcoin</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Adresa introdusa nu este valida</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Te rugam verifica adresa si introduce-o din nou</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Adresa introdusa nu se refera la o cheie.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Blocarea portofelului a fost intrerupta</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Cheia privata pentru adresa introdusa nu este valida.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Semnarea mesajului a esuat</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mesaj Semnat!</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Aceasta semnatura nu a putut fi decodata</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Verifica semnatura si incearca din nou</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Semnatura nu seamana!</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Verificarea mesajului a esuat</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mesaj verificat</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Deschis pân? la %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>conflictual</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/deconectat</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/neconfirmat</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirm?ri</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stare</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, nu s-a propagat înc?</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sursa</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De la</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>necunoscut</translation>
    </message>
    <message>
        <source>To</source>
        <translation>C?tre</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>Adresa posedata</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etichet?</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nu este acceptat</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comisionul tranzac?iei</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Suma net?</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesaj</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentarii</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantitate</translation>
    </message>
    <message>
        <source>true</source>
        <translation>Adevarat!</translation>
    </message>
    <message>
        <source>false</source>
        <translation>Fals!</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detaliile tranzac?iei</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Acest panou arată o descriere detaliată a tranzacţiei</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipul</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantitate</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Deschis pân? la %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Deconectat</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Neconfirmat</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmat (%1 confirm?ri)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Conflictual</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generat dar neacceptat</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recep?ionat cu</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Primit de la</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Trimis c?tre</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Plat? c?tre tine</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Starea tranzac?iei. Treci cu mausul peste acest câmp pentru afi?area num?rului de confirm?ri.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data ?i ora la care a fost recep?ionat? tranzac?ia.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipul tranzac?iei.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Adresa de destina?ie a tranzac?iei.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Suma extras? sau ad?ugat? la sold.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Ast?zi</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>S?pt?mâna aceasta</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Luna aceasta</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Luna trecut?</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Anul acesta</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Între...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recep?ionat cu</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Trimis c?tre</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>C?tre tine</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Produs</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altele</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Cantitatea minim?</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiaz? adresa</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiaz? eticheta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiaz? suma</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiaz? ID tranzac?ie</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editeaz? eticheta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Arat? detaliile tranzac?iei</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exporta datele trazactiei</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipul</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichet?</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres?</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sum?</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Eroare la exportare</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Nu s-a putut scrie în fi?ier %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Interval:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>c?tre</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Se trimite...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>A intervenit o eroare in timp ce se seta portul RPC %u pentru ascultare pe IPv6, reintoarcere la IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>A intervenit o eroare in timp ce se seta portul RPC %u pentru ascultare pe IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uz:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>List? de comenzi</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Ajutor pentru o comand?</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Atentie: setarea -paytxfee este foarte ridicata! Aceasta este taxa tranzactiei pe care o vei plati daca trimiti o tranzactie.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Atentie: fisierul wallet.dat este corupt, date salvate! Fisierul original wallet.dat a fost salvat ca wallet.{timestamp}.bak in %s; daca balansul sau tranzactiile sunt incorecte ar trebui sa restaurati dintr-o copie de siguranta. </translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Atentie: eroare la citirea fisierului wallet.dat! Toate cheile sunt citite corect, dar datele tranzactiei sau anumite intrari din agenda sunt incorecte sau lipsesc.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Eroare: crearea tranzac?iei a e?uat.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Eroare: tranzac?ia a fost respins?. Acest lucru s-ar putea întâmpla în cazul în care unele dintre monedele din portofel au fost deja cheltuite, cum si cum a?i utilizat o copie a wallet.dat ?i monedele au fost cheltuite în copie dar nu au fost marcate ca ?i cheltuite aici.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Nu s-a reuşit ascultarea pe orice port. Folosiţi -listen=0 dacă vreţi asta.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Pentru a folosi op?iunea %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Trebuie sa setezi rpcpassword=&lt;password&gt; în fi?ierul de configurare:?
%s?
Dac? fi?ierul nu exist?, creeaz?-l cu permisiuni de citire doar de c?tre proprietar.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Versiune Gridcoin</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Suma nevalid? pentru -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Suma invalida pentru -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Portofelul %s este in afara directorului %s</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Se verifica integritatea bazei de date...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Eroare la ini?ializarea mediu de baze de date %s! Pentru a recupera, SALVATI ACEL DIRECTORr, apoi scoate?i totul din el, cu excep?ia wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corupt, recuperare e?uat?</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Adresa -proxy nevalidă: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Adresa -tor invalida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Nu se poate rezolva adresa -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Nu se poate rezolva adresa -externalip: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Suma invalida pentru -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Eroare la înc?rcarea blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Eroare la înc?rcarea wallet.dat: Portofel corupt</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Eroare la înc?rcarea wallet.dat: Portofelul necesita o versiune mai noua de Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>A fost nevoie de rescrierea portofelului: restarta?i Gridcoin pentru a finaliza</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Eroare la înc?rcarea wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Se importa fisierul bootstrap blockchain</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Încărcare adrese...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Eroare: nodul nu a putut fi pornit</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Imposibil de conectat %s pe acest computer. Cel mai probabil Gridcoin ruleaza</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Nu se poate folosi %s pe acest calculator (eroarea returnat? este %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Eroare: portofel blocat, tranzactia nu s-a creat</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Eroare: portofel blocat doar pentru staking, tranzactia nu s-a creat.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Eroare: Aceast? tranzac?ie necesit? un comision de tranzac?ie de cel pu?in %s din cauza valorii sale, complexitate, sau utilizarea de fonduri recent primite</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Se trimite...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Sum? nevalid?</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Atentie: Va rugam verificati ca timpul si data calculatorului sunt corete. Daca timpul este gresit Gridcoin nu va functiona corect.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Avertisment: spa?iul pe disc este sc?zut!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Reţeaua specificată în -onlynet este necunoscută: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fonduri insuficiente</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Încărcare index bloc...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Încărcare portofel...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nu se poate scrie adresa implicită</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Rescanare...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Încărcare terminată</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
</context>
</TS>